@@ -11,7 +11,7 @@ from lxml import etree
 from io import BytesIO
 from opf_newparser import Opf_Parser
 from hrefutils import startingDir, buildBookPath, buildRelativePath
-
+from collections import OrderedDict
 
 ASCII_CHARS   = set(chr(x) for x in range(128))
 URL_SAFE      = set('ABCDEFGHIJKLMNOPQRSTUVWXYZ'
@@ -70,7 +70,7 @@ def _well_formed(data):
     if isinstance(newdata, str):
         newdata = newdata.encode('utf-8')
     try:
-        parser = etree.XMLParser(encoding='utf-8', recover=False)
+        parser = etree.XMLParser(encoding='utf-8', recover=False, resolve_entities=False)
         tree = etree.parse(BytesIO(newdata), parser)
     except Exception:
         result = False
@@ -81,7 +81,7 @@ def _reformat(data):
     newdata = data
     if isinstance(newdata, str):
         newdata = newdata.encode('utf-8')
-    parser = etree.XMLParser(encoding='utf-8', recover=True, ns_clean=True, 
+    parser = etree.XMLParser(encoding='utf-8', recover=True, ns_clean=True,
                              remove_comments=True, remove_pis=True, strip_cdata=True, resolve_entities=False)
     tree = etree.parse(BytesIO(newdata), parser)
     newdata = etree.tostring(tree.getroot(),encoding='UTF-8', xml_declaration=False)
@@ -154,7 +154,7 @@ def WellFormedXMLErrorCheck(data, mtype=""):
     column = "-1"
     message = "well-formed"
     try:
-        parser = etree.XMLParser(encoding='utf-8', recover=False)
+        parser = etree.XMLParser(encoding='utf-8', recover=False, resolve_entities=False)
         tree = etree.parse(BytesIO(newdata), parser)
     except Exception:
         line = "0"
@@ -207,7 +207,7 @@ def anchorNCXUpdates(data, ncx_bookpath, originating_bookpath, keylist, valuelis
     # lxml on a Mac does not seem to handle full unicode properly, so encode as utf-8
     data = data.encode('utf-8')
     # rebuild serialized lookup dictionary
-    id_dict = {}
+    id_dict = OrderedDict()
     for i in range(0, len(keylist)):
         id_dict[ keylist[i] ] = valuelist[i]
     startdir = startingDir(ncx_bookpath)
@@ -260,7 +260,7 @@ def performNCXSourceUpdates(data, newbkpath, oldbkpath, keylist, valuelist):
     # lxml on a Mac does not seem to handle full unicode properly, so encode as utf-8
     data = data.encode('utf-8')
     # rebuild serialized lookup dictionary
-    updates = {}
+    updates = OrderedDict()
     for i in range(0, len(keylist)):
         updates[ keylist[i] ] = valuelist[i]
     xmlbuilder = LXMLTreeBuilderForXML(parser=None, empty_element_tags=ebook_xml_empty_tags)
@@ -290,7 +290,7 @@ def performOPFSourceUpdates(data, newbkpath, oldbkpath, keylist, valuelist):
     # lxml on a Mac does not seem to handle full unicode properly, so encode as utf-8
     data = data.encode('utf-8')
     # rebuild serialized lookup dictionary
-    updates = {}
+    updates = OrderedDict()
     for i in range(0, len(keylist)):
         updates[ keylist[i] ] = valuelist[i]
     xmlbuilder = LXMLTreeBuilderForXML(parser=None, empty_element_tags=ebook_xml_empty_tags)
@@ -323,7 +323,7 @@ def performSMILUpdates(data, newbkpath, oldbkpath, keylist, valuelist):
     # lxml on a Mac does not seem to handle full unicode properly, so encode as utf-8
     data = data.encode('utf-8')
     # rebuild serialized lookup dictionary of xml_updates, properly adjusted
-    updates = {}
+    updates = OrderedDict()
     for i in range(0, len(keylist)):
         updates[ keylist[i] ] = valuelist[i]
     xml_empty_tags = ["text", "audio"]
@@ -357,7 +357,7 @@ def performPageMapUpdates(data, newbkpath, oldbkpath, keylist, valuelist):
     # lxml on a Mac does not seem to handle full unicode properly, so encode as utf-8
     data = data.encode('utf-8')
     # rebuild serialized lookup dictionary of xml_updates properly adjusted
-    updates = {}
+    updates = OrderedDict()
     for i in range(0, len(keylist)):
         updates[ keylist[i] ] = valuelist[i]
     xml_empty_tags = ["page"]
